package weather

import (
	"time"
)

// Stable intermediate struct containing superset of fields
// between AWN and Wunderground style updates from Ambient devices
type WeatherUpdate struct {
	DateUTC         *time.Time
	StationType     string
	TempOutdoorF    float64
	TempIndoorF     float64
	HumidityOudoor  int
	HumidityIndoor  int
	WindSpeedMPH    float64
	WindGustMPH     float64
	MaxDailyGust    float64
	WindDir         int
	WindDirAvg10m   int
	UV              int
	SolarRadiation  float64
	HourlyRainIn    float64
	EventRainIn     float64
	DailyRainIn     float64
	WeeklyRainIn    float64
	MonthlyRainIn   float64
	YearlyRainIn    float64
	TotalRainIn     float64
	Batteries       []BatteryStatus
	BaromRelativeIn float64
	BaromAbsoluteIn float64
	// These fields may be calculated
	// if not otherwise set
	DewPointF  float64
	WindChillF float64
}

type BatteryStatus struct {
	Component string
	Status    int
}

type WeatherUpdateField string

// NOTE: Annoyance to avoid string constant comparisons
// CHORE: Maintain this
const (
	FieldDateUTC         WeatherUpdateField = "DateUTC"
	FieldStationType     WeatherUpdateField = "StationType"
	FieldTempOutdoorF    WeatherUpdateField = "TempOutdoorF"
	FieldTempIndoorF     WeatherUpdateField = "TempIndoorF"
	FieldHumidityOudoor  WeatherUpdateField = "HumidityOudoor"
	FieldHumidityIndoor  WeatherUpdateField = "HumidityIndoor"
	FieldWindSpeedMPH    WeatherUpdateField = "WindSpeedMPH"
	FieldWindGustMPH     WeatherUpdateField = "WindGustMPH"
	FieldMaxDailyGust    WeatherUpdateField = "MaxDailyGust"
	FieldWindDir         WeatherUpdateField = "WindDir"
	FieldWindDirAvg10m   WeatherUpdateField = "WindDirAvg10m"
	FieldUV              WeatherUpdateField = "UV"
	FieldSolarRadiation  WeatherUpdateField = "SolarRadiation"
	FieldHourlyRainIn    WeatherUpdateField = "HourlyRainIn"
	FieldEventRainIn     WeatherUpdateField = "EventRainIn"
	FieldDailyRainIn     WeatherUpdateField = "DailyRainIn"
	FieldWeeklyRainIn    WeatherUpdateField = "WeeklyRainIn"
	FieldMonthlyRainIn   WeatherUpdateField = "MonthlyRainIn"
	FieldYearlyRainIn    WeatherUpdateField = "YearlyRainIn"
	FieldTotalRainIn     WeatherUpdateField = "TotalRainIn"
	FieldBatteries       WeatherUpdateField = "Batteries"
	FieldBaromRelativeIn WeatherUpdateField = "BaromRelativeIn"
	FieldBaromAbsoluteIn WeatherUpdateField = "BaromAbsoluteIn"
	FieldDewPointF       WeatherUpdateField = "DewPointF"
	FieldWindChillF      WeatherUpdateField = "WindChillF"
)
